==> Audit-DBI-TT2-2.1.1.tar.gz: Audit-DBI-TT2-2.1.1/README.md <==
Audit-DBI-TT2
=============

[![Build Status](https://travis-ci.org/guillaumeaubert/Audit-DBI-TT2.png?branch=master)](https://travis-ci.org/guillaumeaubert/Audit-DBI-TT2)

A Template Toolkit plugin to display audit events recorded by [Audit::DBI]
(https://metacpan.org/release/Audit-DBI).


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Audit::DBI::TT2


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Audit-DBI-TT2/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Audit-DBI-TT2)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Audit-DBI-TT2)

 * [MetaCPAN]
   (https://metacpan.org/release/Audit-DBI-TT2)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2010-2013 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> Audit-DBI-TT2-2.2.3.tar.gz: Audit-DBI-TT2-2.2.3/README.md <==
Audit-DBI-TT2
=============

[![Build Status](https://travis-ci.org/guillaumeaubert/Audit-DBI-TT2.png?branch=master)](https://travis-ci.org/guillaumeaubert/Audit-DBI-TT2)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/Audit-DBI-TT2/badge.png?branch=master)](https://coveralls.io/r/guillaumeaubert/Audit-DBI-TT2?branch=master)

A Template Toolkit plugin to display audit events recorded by [Audit::DBI]
(https://metacpan.org/release/Audit-DBI).


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Audit::DBI::TT2


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Audit-DBI-TT2/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Audit-DBI-TT2)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Audit-DBI-TT2)

 * [MetaCPAN]
   (https://metacpan.org/release/Audit-DBI-TT2)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2010-2013 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
